@@ -1,11 +1,8 @@
-# Moved globals from Pweb, check to see after move each for invalid references!
-
 
 rcParams = {"figdir": "figures",
             "usematplotlib": True,
             "storeresults": False,
             "cachedir": 'cache',
-            "shell_path": "python",
             "chunk": {"defaultoptions": {
                 "echo": True,
                 "results": 'verbatim',
@@ -15,19 +12,20 @@ rcParams = {"figdir": "figures",
                 "caption": False,
                 "term": False,
                 "name": None,
-                "wrap": True,
+                "wrap": "output",
                 "f_pos": "htpb",
-                "f_size": (8, 6),
+                "f_size": (6, 4),
                 "f_env": None,
+                "dpi" : 200,
                 "f_spines": True,
                 "complete": True,
-                "engine": "python",
                 "option_string": "",
+                "display_data" : True,
+                "display_stream" : True
             }
-            }
+    }
 }
 
-
 class PwebProcessorGlobals(object):
     """A class to hold the globals used in processors"""
-    globals = {}
\ No newline at end of file
+    globals = {}
